@@ -20,7 +20,7 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-require 'libyajl2'
+require "libyajl2"
 
 # Mixin for use in finding the right yajl library on the system.  The 'caller'
 # needs to also mixin either the FFI module or the DLopen module.  Those are
@@ -36,7 +36,7 @@ module FFI_Yajl
     # @api private
     # @return Array<String> lower case ruby host_os string
     def host_os
-      RbConfig::CONFIG['host_os'].downcase
+      RbConfig::CONFIG["host_os"].downcase
     end
 
     # Array of yajl library names on the platform.  Some platforms like Windows
@@ -103,7 +103,7 @@ module FFI_Yajl
         rescue LoadError
         end
       end
-      ffi_lib 'yajl' unless found
+      ffi_lib "yajl" unless found
     end
   end
 end
